@@ -79,7 +79,9 @@ I have included with this letter, two chapters of my dissertation, my \\emph{cur
         if(include.opening == TRUE){
         		paste(opening, " ",
         		object$position[i],
-        		" in the ",
+        		" in ",
+        		object$subfield[i],
+        		" at the ",
         		object$dept[i],
         		" at ",
         		object$institution[i],
